pub struct Animator<W: Widget, A: Fn(&mut W, f32) -> Update> { /* private fields */ }Expand description
A widget that animates another widget using an animation function.
Implementations
Sourceimpl<W: Widget, A: Fn(&mut W, f32) -> Update> Animator<W, A>
impl<W: Widget, A: Fn(&mut W, f32) -> Update> Animator<W, A>
Sourcepub fn new(duration: Duration, widget: W, animation: A) -> Self
pub fn new(duration: Duration, widget: W, animation: A) -> Self
Creates a new animator widget with the given duration, child widget and animation function.
The animation function is called with a value between 0.0 and 1.0 based on the elapsed time since the start of the animation
and the total duration of the animation.