pub enum ButtonState {
Idle,
Hovered,
Pressed,
Released,
}Expand description
The internal state of the button.
Variants
Idle
The button is idling (inactive).
Hovered
The cursor is hovering over the button.
Pressed
The cursor is hovering over the button and the left click button is pressed.
Released
The cursor is hovering over the button and the left click button is released.
This is when the on_pressed function is called.