pub struct Button<S: State, W: Widget<S> + 'static> { /* private fields */ }Expand description
An interactive area with a child widget that runs a closure when pressed.
See the counter example for how to use it in practice.
Theming
Styling the button require following properties:
color_pressed- The color of the button when pressed.color_idle- The color of the button when not pressed and not hovered (idling).color_hovered- The color of the button when hovered on.
Implementations