pub struct Container { /* private fields */ }Expand description
A container widget that can display and layout multiple child widgets.
The layout of the children (row, column, etc.) depends on the LayoutStyle of the container.
See the counter example for how to use it in practice.
Theming
The container widget doesn’t actually draw anything but the child widgets, so theming is useless.
The WidgetId is equal to maycoon-widgets:Container.
Implementations