Contains various traits for extending widget capability.
Traits
- Widget
Child Ext - An extension trait for widgets with a single child widget.
- Widget
Children Ext - An extension trait for widgets with multiple child widgets.
- Widget
Layout Ext - An extension trait for widgets with a layout style.