Image

Struct Image 

pub struct Image { /* private fields */ }
An image widget. Pretty self-explanatory.

See the image example for how to use it in practice.

Theming

The widget itself only draws the underlying image, so theming is useless.

Implementations

Source

impl Image

pub fn new(image: impl Into<MaybeSignal<ImageData>>) -> Self

Create an image widget from the given ImageData.

pub fn with_image(self, image: impl Into<MaybeSignal<ImageData>>) -> Self

Set the image.