pub struct Slider { /* private fields */ }Expand description
Implementations
Sourceimpl Slider
impl Slider
Sourcepub fn new(value: impl Into<MaybeSignal<f32>>) -> Self
pub fn new(value: impl Into<MaybeSignal<f32>>) -> Self
Create a new Slider widget from a value (should be a signal) and an on_change callback.
Sourcepub fn with_value(self, value: impl Into<MaybeSignal<f32>>) -> Self
pub fn with_value(self, value: impl Into<MaybeSignal<f32>>) -> Self
Sets the layout style of the slider and returns itself.
Sourcepub fn with_on_change(self, on_change: impl Into<MaybeSignal<Update>>) -> Self
pub fn with_on_change(self, on_change: impl Into<MaybeSignal<Update>>) -> Self
Sets the function to be called when the slider is clicked/changed.