Struct Container

pub struct Container<S: State> { /* private fields */ }
A container widget that can display and layout multiple child widgets.

The layout of the children (row, column, etc.) depends on the LayoutStyle of the container.

See the counter example for how to use it in practice.

Theming

The container widget doesn’t actually draw anything but the child widgets, so theming is useless.

Implementations

Source

impl<S: State> Container<S>

pub fn new(children: Vec<Val<S, Box<dyn Widget<S>>>>) -> Self

Creates a new container with given children.

pub fn add_children(&mut self, children: Vec<Val<S, Box<dyn Widget<S>>>>)

Adds the given children to the container.

pub fn with_children(self, children: Vec<Val<S, Box<dyn Widget<S>>>>) -> Self

Adds the given children to the container and returns itself.

pub fn add_child(&mut self, child: impl Into<Val<S, Box<dyn Widget<S>>>>)

Adds the given child to the container.

pub fn with_child(self, child: impl Into<Val<S, Box<dyn Widget<S>>>>) -> Self

Adds the given child to the container and returns itself.