pub struct Container<S: State> { /* private fields */ }Expand description
A container widget that can display and layout multiple child widgets.
The layout of the children (row, column, etc.) depends on the LayoutStyle of the container.
See the counter example for how to use it in practice.
Theming
The container widget doesn’t actually draw anything but the child widgets, so theming is useless.
Implementations
Sourceimpl<S: State> Container<S>
impl<S: State> Container<S>
Sourcepub fn new(children: Vec<Val<S, Box<dyn Widget<S>>>>) -> Self
pub fn new(children: Vec<Val<S, Box<dyn Widget<S>>>>) -> Self
Creates a new container with given children.
Sourcepub fn add_children(&mut self, children: Vec<Val<S, Box<dyn Widget<S>>>>)
pub fn add_children(&mut self, children: Vec<Val<S, Box<dyn Widget<S>>>>)
Adds the given children to the container.
Sourcepub fn with_children(self, children: Vec<Val<S, Box<dyn Widget<S>>>>) -> Self
pub fn with_children(self, children: Vec<Val<S, Box<dyn Widget<S>>>>) -> Self
Adds the given children to the container and returns itself.