pub struct WidgetFetcher<T: Send + 'static, W: Widget, F: Fn(Option<T>) -> W> { /* private fields */ }Expand description
Widget builder to fetch data from an asynchronous task. The TaskRunner needs to be initialized. This is similar to the FutureBuilder from Flutter.
Async + UI
Normally, a UI Application is not able to asynchronously spawn tasks and will block the UI thread instead of running tasks in the background. The WidgetFetcher is able to spawn asynchronous tasks on a global runner and construct a widget based on the result of the task. You can use it to fetch asynchronous data and either return something like a loading screen or the actual data.
Workflow of a WidgetFetcher.
- Run the task in the background using the TaskRunner.
- Construct the widget with None as the result (task is still loading).
- Once the task is done, update the UI with the new result and trigger an Update.
Theming
The widget itself only draws the underlying widget, so theming is useless.
Implementations
Sourceimpl<T: Send + 'static, W: Widget, F: Fn(Option<T>) -> W> WidgetFetcher<T, W, F>
impl<T: Send + 'static, W: Widget, F: Fn(Option<T>) -> W> WidgetFetcher<T, W, F>
Sourcepub fn new<Fut>(future: Fut, update: Update, render: F) -> Self
pub fn new<Fut>(future: Fut, update: Update, render: F) -> Self
Creates a new WidgetFetcher with parameters:
future: The future to execute.update: The update to trigger when the data is updated (from loading to done).render: The function to render the widget. The first parameter is the result of the future and the second parameter is the mutable app state.