pub struct Slider<S: State> { /* private fields */ }Expand description
A slider widget to control a floating point value between 0.0 and 1.0.
Theming
You can style the slider using following properties:
color- The color of the slider bar.color_ball- The color of the slider ball.
Implementations
Sourceimpl<S: State> Slider<S>
impl<S: State> Slider<S>
Sourcepub fn new(
value: impl Into<Val<S, f32>>,
on_change: impl FnMut(&mut S, f32) -> Update + 'static,
) -> Self
pub fn new( value: impl Into<Val<S, f32>>, on_change: impl FnMut(&mut S, f32) -> Update + 'static, ) -> Self
Create a new Slider widget from a value (should be state bound) and an on_change callback.
Sourcepub fn with_value(self, value: impl Into<Val<S, f32>>) -> Self
pub fn with_value(self, value: impl Into<Val<S, f32>>) -> Self
Sets the layout style of the slider and returns itself.